==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/systests/transport-jms/src/test/java/org/apache/cxf/systest/jms/GreeterImplQueueDecoupledOneWaysDeferredReply.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jms;

import javax.jws.WebService;

import org.apache.cxf.hello_world_jms.HelloWorldOneWayPort;



@WebService(serviceName = "HelloWorldQueueDecoupledOneWaysService",
            portName = "HelloWorldQueueDecoupledOneWaysReplyPort",
            endpointInterface = "org.apache.cxf.hello_world_jms.HelloWorldOneWayPort",
            targetNamespace = "http://cxf.apache.org/hello_world_jms",
            wsdlLocation = "testutils/jms_test.wsdl")
public class GreeterImplQueueDecoupledOneWaysDeferredReply implements HelloWorldOneWayPort {

    private String request;
    private Throwable asyncEx;

    public void greetMeOneWay(String value) {
        synchronized (this) {
            request = value;
            notifyAll();
        }

    }
    public String ackRequest(long timeout) {
        synchronized (this) {
            try {
                wait(timeout);
            } catch (InterruptedException e) {
                asyncEx = e;
                return null;
            }
        }
        return request;
    }

    public Throwable getException() {
        return asyncEx;
    }
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/transport-jms/src/test/java/org/apache/cxf/systest/jms/GreeterImplQueueDecoupledOneWaysDeferredReply.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jms;

import jakarta.jws.WebService;
import org.apache.cxf.hello_world_jms.HelloWorldOneWayPort;



@WebService(serviceName = "HelloWorldQueueDecoupledOneWaysService",
            portName = "HelloWorldQueueDecoupledOneWaysReplyPort",
            endpointInterface = "org.apache.cxf.hello_world_jms.HelloWorldOneWayPort",
            targetNamespace = "http://cxf.apache.org/hello_world_jms",
            wsdlLocation = "testutils/jms_test.wsdl")
public class GreeterImplQueueDecoupledOneWaysDeferredReply implements HelloWorldOneWayPort {

    private String request;
    private Throwable asyncEx;

    public void greetMeOneWay(String value) {
        synchronized (this) {
            request = value;
            notifyAll();
        }

    }
    public String ackRequest(long timeout) {
        synchronized (this) {
            try {
                wait(timeout);
            } catch (InterruptedException e) {
                asyncEx = e;
                return null;
            }
        }
        return request;
    }

    public Throwable getException() {
        return asyncEx;
    }
}
